@@ -349,9 +349,10 @@ class MainWindow(tkinter.Tk):
 
     def cmd_menu_mcp(self, *args):
         name = self.var_default_mcp.get()
-        if name is not "GBAR's MCP":
+        if name in self.default_mcp_names:
             self.mcp_param = self.default_mcp[self.default_mcp_names == name][0]
             self.str_mcp_param.set(self.mcp_param.__repr__())
+            self.var_default_mcp.set("GBAR's MCP")
 
 
 ###############################################################################
