@@ -8,7 +8,7 @@ Created on Thu Dec 10 15:07:10 2020
 
 from GBARpy.Main_window import MainWindow
 # Uncomment for edit mode
-# from Main_window import MainWindow
+from Main_window import MainWindow
 
 print('  _|_|_|  _|_|_|      _|_|    _|_|_|  ', '\n',
       '_|        _|    _|  _|    _|  _|    _|', '\n',
